@@ -2,21 +2,21 @@ use std::{f32::consts::PI, panic::panic_any, time::Instant};
 
 extern crate dubins_paths;
 
-use dubins_paths::{DubinsPath, DubinsPathType};
-pub const MAX_TURN_RADIUS: f32 = 1. / 0.00076;
+use dubins_paths::{DubinsPath, DubinsPathType, DubinsPos};
+const TURN_RADIUS: f32 = 1. / 0.00076;
 
 #[test]
 fn fast_shortest_csc_path() {
     let runs = 10000000;
-    let mut times = Vec::new();
+    let mut times = Vec::with_capacity(runs);
 
     for _ in 0..runs {
         let start = Instant::now();
 
-        let q0 = [2000., 2000., 0.];
-        let q1 = [0., 0., PI];
+        let q0: DubinsPos = [2000., 2000., 0.];
+        let q1: DubinsPos = [0., 0., PI];
 
-        if let Err(err) = DubinsPath::shortest_in(q0, q1, MAX_TURN_RADIUS, &DubinsPathType::CCC) {
+        if let Err(err) = DubinsPath::shortest_in(q0, q1, TURN_RADIUS, &DubinsPathType::CCC) {
             panic_any(err);
         }
 
@@ -33,15 +33,15 @@ fn fast_shortest_csc_path() {
 #[test]
 fn fast_shortest_ccc_path() {
     let runs = 10000000;
-    let mut times = Vec::new();
+    let mut times = Vec::with_capacity(runs);
 
     for _ in 0..runs {
         let start = Instant::now();
 
-        let q0 = [2000., 2000., 0.];
-        let q1 = [0., 0., PI];
+        let q0: DubinsPos = [2000., 2000., 0.];
+        let q1: DubinsPos = [0., 0., PI];
 
-        if let Err(err) = DubinsPath::shortest_in(q0, q1, MAX_TURN_RADIUS, &DubinsPathType::CSC) {
+        if let Err(err) = DubinsPath::shortest_in(q0, q1, TURN_RADIUS, &DubinsPathType::CSC) {
             panic_any(err);
         }
 
@@ -58,15 +58,15 @@ fn fast_shortest_ccc_path() {
 #[test]
 fn fast_shortest_path() {
     let runs = 10000000;
-    let mut times = Vec::new();
+    let mut times = Vec::with_capacity(runs);
 
     for _ in 0..runs {
         let start = Instant::now();
 
-        let q0 = [2000., 2000., 0.];
-        let q1 = [0., 0., PI];
+        let q0: DubinsPos = [2000., 2000., 0.];
+        let q1: DubinsPos = [0., 0., PI];
 
-        if let Err(err) = DubinsPath::shortest_from(q0, q1, MAX_TURN_RADIUS) {
+        if let Err(err) = DubinsPath::shortest_from(q0, q1, TURN_RADIUS) {
             panic_any(err);
         }
 
@@ -83,12 +83,12 @@ fn fast_shortest_path() {
 #[test]
 fn fast_many_sample() {
     let runs = 100000;
-    let mut times = Vec::new();
+    let mut times = Vec::with_capacity(runs);
 
-    let q0 = [2000., 2000., 0.];
-    let q1 = [0., 0., PI];
+    let q0: DubinsPos = [2000., 2000., 0.];
+    let q1: DubinsPos = [0., 0., PI];
 
-    let path = match DubinsPath::shortest_from(q0, q1, MAX_TURN_RADIUS) {
+    let path = match DubinsPath::shortest_from(q0, q1, TURN_RADIUS) {
         Ok(p) => p,
         Err(err) => panic_any(err),
     };
@@ -96,7 +96,7 @@ fn fast_many_sample() {
     for _ in 0..runs {
         let start = Instant::now();
 
-        path.sample_many(20.);
+        path.sample_many(10.);
 
         times.push(start.elapsed().as_secs_f32());
     }
